@@ -3,9 +3,9 @@ Main interface for dynamodbstreams service type definitions.
 
 Usage::
 
-    from mypy_boto3.dynamodbstreams.type_defs import KeySchemaElementTypeDef
+    from mypy_boto3.dynamodbstreams.type_defs import AttributeValueTypeDef
 
-    data: KeySchemaElementTypeDef = {...}
+    data: AttributeValueTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,59 +22,21 @@ else:
 
 
 __all__ = (
+    "AttributeValueTypeDef",
+    "IdentityTypeDef",
     "KeySchemaElementTypeDef",
+    "RecordTypeDef",
     "SequenceNumberRangeTypeDef",
     "ShardTypeDef",
     "StreamDescriptionTypeDef",
-    "DescribeStreamOutputTypeDef",
-    "IdentityTypeDef",
-    "AttributeValueTypeDef",
     "StreamRecordTypeDef",
-    "RecordTypeDef",
+    "StreamTypeDef",
+    "DescribeStreamOutputTypeDef",
     "GetRecordsOutputTypeDef",
     "GetShardIteratorOutputTypeDef",
-    "StreamTypeDef",
     "ListStreamsOutputTypeDef",
 )
 
-KeySchemaElementTypeDef = TypedDict(
-    "KeySchemaElementTypeDef", {"AttributeName": str, "KeyType": Literal["HASH", "RANGE"]}
-)
-
-SequenceNumberRangeTypeDef = TypedDict(
-    "SequenceNumberRangeTypeDef",
-    {"StartingSequenceNumber": str, "EndingSequenceNumber": str},
-    total=False,
-)
-
-ShardTypeDef = TypedDict(
-    "ShardTypeDef",
-    {"ShardId": str, "SequenceNumberRange": SequenceNumberRangeTypeDef, "ParentShardId": str},
-    total=False,
-)
-
-StreamDescriptionTypeDef = TypedDict(
-    "StreamDescriptionTypeDef",
-    {
-        "StreamArn": str,
-        "StreamLabel": str,
-        "StreamStatus": Literal["ENABLING", "ENABLED", "DISABLING", "DISABLED"],
-        "StreamViewType": Literal["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"],
-        "CreationRequestDateTime": datetime,
-        "TableName": str,
-        "KeySchema": List[KeySchemaElementTypeDef],
-        "Shards": List[ShardTypeDef],
-        "LastEvaluatedShardId": str,
-    },
-    total=False,
-)
-
-DescribeStreamOutputTypeDef = TypedDict(
-    "DescribeStreamOutputTypeDef", {"StreamDescription": StreamDescriptionTypeDef}, total=False
-)
-
-IdentityTypeDef = TypedDict("IdentityTypeDef", {"PrincipalId": str, "Type": str}, total=False)
-
 AttributeValueTypeDef = TypedDict(
     "AttributeValueTypeDef",
     {
@@ -92,18 +54,10 @@ AttributeValueTypeDef = TypedDict(
     total=False,
 )
 
-StreamRecordTypeDef = TypedDict(
-    "StreamRecordTypeDef",
-    {
-        "ApproximateCreationDateTime": datetime,
-        "Keys": Dict[str, AttributeValueTypeDef],
-        "NewImage": Dict[str, AttributeValueTypeDef],
-        "OldImage": Dict[str, AttributeValueTypeDef],
-        "SequenceNumber": str,
-        "SizeBytes": int,
-        "StreamViewType": Literal["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"],
-    },
-    total=False,
+IdentityTypeDef = TypedDict("IdentityTypeDef", {"PrincipalId": str, "Type": str}, total=False)
+
+KeySchemaElementTypeDef = TypedDict(
+    "KeySchemaElementTypeDef", {"AttributeName": str, "KeyType": Literal["HASH", "RANGE"]}
 )
 
 RecordTypeDef = TypedDict(
@@ -114,15 +68,65 @@ RecordTypeDef = TypedDict(
         "eventVersion": str,
         "eventSource": str,
         "awsRegion": str,
-        "dynamodb": StreamRecordTypeDef,
-        "userIdentity": IdentityTypeDef,
+        "dynamodb": "StreamRecordTypeDef",
+        "userIdentity": "IdentityTypeDef",
     },
     total=False,
 )
 
+SequenceNumberRangeTypeDef = TypedDict(
+    "SequenceNumberRangeTypeDef",
+    {"StartingSequenceNumber": str, "EndingSequenceNumber": str},
+    total=False,
+)
+
+ShardTypeDef = TypedDict(
+    "ShardTypeDef",
+    {"ShardId": str, "SequenceNumberRange": "SequenceNumberRangeTypeDef", "ParentShardId": str},
+    total=False,
+)
+
+StreamDescriptionTypeDef = TypedDict(
+    "StreamDescriptionTypeDef",
+    {
+        "StreamArn": str,
+        "StreamLabel": str,
+        "StreamStatus": Literal["ENABLING", "ENABLED", "DISABLING", "DISABLED"],
+        "StreamViewType": Literal["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"],
+        "CreationRequestDateTime": datetime,
+        "TableName": str,
+        "KeySchema": List["KeySchemaElementTypeDef"],
+        "Shards": List["ShardTypeDef"],
+        "LastEvaluatedShardId": str,
+    },
+    total=False,
+)
+
+StreamRecordTypeDef = TypedDict(
+    "StreamRecordTypeDef",
+    {
+        "ApproximateCreationDateTime": datetime,
+        "Keys": Dict[str, "AttributeValueTypeDef"],
+        "NewImage": Dict[str, "AttributeValueTypeDef"],
+        "OldImage": Dict[str, "AttributeValueTypeDef"],
+        "SequenceNumber": str,
+        "SizeBytes": int,
+        "StreamViewType": Literal["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"],
+    },
+    total=False,
+)
+
+StreamTypeDef = TypedDict(
+    "StreamTypeDef", {"StreamArn": str, "TableName": str, "StreamLabel": str}, total=False
+)
+
+DescribeStreamOutputTypeDef = TypedDict(
+    "DescribeStreamOutputTypeDef", {"StreamDescription": "StreamDescriptionTypeDef"}, total=False
+)
+
 GetRecordsOutputTypeDef = TypedDict(
     "GetRecordsOutputTypeDef",
-    {"Records": List[RecordTypeDef], "NextShardIterator": str},
+    {"Records": List["RecordTypeDef"], "NextShardIterator": str},
     total=False,
 )
 
@@ -130,12 +134,8 @@ GetShardIteratorOutputTypeDef = TypedDict(
     "GetShardIteratorOutputTypeDef", {"ShardIterator": str}, total=False
 )
 
-StreamTypeDef = TypedDict(
-    "StreamTypeDef", {"StreamArn": str, "TableName": str, "StreamLabel": str}, total=False
-)
-
 ListStreamsOutputTypeDef = TypedDict(
     "ListStreamsOutputTypeDef",
-    {"Streams": List[StreamTypeDef], "LastEvaluatedStreamArn": str},
+    {"Streams": List["StreamTypeDef"], "LastEvaluatedStreamArn": str},
     total=False,
 )
